# Changelog

All notable changes to this project will be documented in this file.

The CHANGELOG is powered by [Commitizen](https://commitizen-tools.github.io/commitizen/).

## v1.0.6 (2025-05-29)

### Fix

- **ci**: i beg this is the last one

## v1.0.5 (2025-05-29)

### Fix

- add twine to dev deps

## v1.0.4 (2025-05-29)

### Fix

- upgrade of twine

## v1.0.3 (2025-05-29)

### Fix

- **pyproject**: try tu upgrade twine
- **pyproject**: use compatible hatchling version <https://github.com/astral-sh/rye/issues/1446>

## v1.0.2 (2025-05-29)

### Fix

- **workflows**: remove ci build and fix inf. loop
- mypy violations

## v1.0.1 (2025-05-29)

### Fix

- version bumping and CHANGELOG keeping tools
- **pyproject**: fix section with deps from uv autogen to supported

## v1.0.0 (2025-05-29)

### Feat

- implement tf2ss conversion and time response functionalities
- add initial project structure with .gitignore, pre-commit configuration, contributing guidelines, license, README, and project metadata
